@@ -173,89 +173,6 @@ RGDAL_GetDescription(SEXP sxpObj) {
 
 }
 
-SEXP
-RGDAL_GetMetadata(SEXP sxpObj, SEXP sxpDomain) {
-
-  void *pGDALObj = getGDALObjPtr(sxpObj);
-
-  const char *domain = asString(sxpDomain);
-
-  char **metadata = ((GDALMajorObject *)pGDALObj)->GetMetadata(domain);
-
-  if (metadata == NULL) return(R_NilValue);
-
-  metadata = CSLDuplicate(metadata);
-
-  SEXP sxpMetadata, sxpNames;
-
-  PROTECT(sxpMetadata = allocVector(VECSXP, CSLCount(metadata)));
-
-  PROTECT(sxpNames = allocVector(STRSXP, CSLCount(metadata)));
-  
-  int i;
-  for (i = 0; i < CSLCount(metadata); ++i) {
-
-    const char *field = CSLGetField(metadata, i);
-
-    char *tag = NULL;
-
-    const char *value = CPLParseNameValue(field, &tag);
-
-    SET_VECTOR_ELT(sxpMetadata, i, value ? mkChar(value) : mkChar(""));
-
-    SET_STRING_ELT(sxpNames, i, tag ? mkChar(tag) : mkChar(""));
-
-  }
-
-  setAttrib(sxpMetadata, R_NamesSymbol, sxpNames);
-
-  UNPROTECT(2);
-
-  return(sxpMetadata);
-
-}
-
-SEXP
-RGDAL_SetMetadata(SEXP sxpObj, SEXP sxpMetadataList) {
-
-  void *pGDALObj = getGDALObjPtr(sxpObj);
-
-  SEXP sxpNames = getAttrib(sxpMetadataList, R_NamesSymbol);
-
-  char **metadata = (char **) CPLCalloc(1, sizeof(char *));
-
-  const char *name, *value;
-
-  if (isNull(sxpNames)) {
-
-    int i;
-    for (i = 0; i < length(sxpMetadataList); ++i) {
-     
-      value = asString(VECTOR_ELT(sxpMetadataList, i));
-      CSLAddString(metadata, value);
-  
-    }
-
-  } else {
-
-    int i;
-    for (i = 0; i < length(sxpMetadataList); ++i) {
-
-      name = asString(sxpNames, i);
-      value = asString(VECTOR_ELT(sxpMetadataList, i));
-      CSLAddNameValue(metadata, name, value);
-		      
-    }
-
-  }
-
-  CPLErr err = ((GDALMajorObject *)pGDALObj)->SetMetadata(metadata, NULL);
-
-  if (err == CE_Failure) warning("Failed to set metadata\n");
-
-  return(sxpObj);
-
-}
 
 SEXP
 RGDAL_GetDriverNames(void) {
